package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Assert;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.ISettingDictTypeService;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.setting.DictTypeCreateValidate;
import com.mdd.admin.validate.setting.DictTypeUpdateValidate;
import com.mdd.admin.vo.setting.SettingDictTypeVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.setting.DictType;
import com.mdd.common.mapper.setting.DictTypeMapper;
import com.mdd.common.util.TimeUtils;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

@Service
public class SettingDictTypeServiceImpl implements ISettingDictTypeService {
   @Resource
   DictTypeMapper dictTypeMapper;

   public List<SettingDictTypeVo> all() {
      QueryWrapper<DictType> queryWrapper = new QueryWrapper();
      queryWrapper.select(new String[]{"id,dict_name,dict_type,dict_remark,dict_status,create_time,update_time"});
      queryWrapper.eq("is_delete", 0);
      queryWrapper.orderByDesc("id");
      List<DictType> dictTypeList = this.dictTypeMapper.selectList(queryWrapper);
      List<SettingDictTypeVo> list = new LinkedList();
      Iterator var4 = dictTypeList.iterator();

      while(var4.hasNext()) {
         DictType dictType = (DictType)var4.next();
         SettingDictTypeVo vo = new SettingDictTypeVo();
         BeanUtils.copyProperties(dictType, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(dictType.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(dictType.getUpdateTime()));
         list.add(vo);
      }

      return list;
   }

   public PageResult<SettingDictTypeVo> list(PageValidate pageValidate, Map<String, String> params) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      QueryWrapper<DictType> queryWrapper = new QueryWrapper();
      queryWrapper.select(new String[]{"id,dict_name,dict_type,dict_remark,dict_status,create_time,update_time"});
      queryWrapper.eq("is_delete", 0);
      queryWrapper.orderByDesc("id");
      this.dictTypeMapper.setSearch(queryWrapper, params, new String[]{"like:dictName@dict_name:str", "like:dictType@dict_type:str", "=:dictStatus@dict_status:int"});
      IPage<DictType> iPage = this.dictTypeMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<SettingDictTypeVo> list = new LinkedList();
      Iterator var8 = iPage.getRecords().iterator();

      while(var8.hasNext()) {
         DictType dictType = (DictType)var8.next();
         SettingDictTypeVo vo = new SettingDictTypeVo();
         BeanUtils.copyProperties(dictType, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(dictType.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(dictType.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public SettingDictTypeVo detail(Integer id) {
      DictType dictType = (DictType)this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,dict_name,dict_type,dict_remark,dict_status,create_time,update_time"}).eq("id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(dictType, "字典类型不存在！", new Object[0]);
      SettingDictTypeVo vo = new SettingDictTypeVo();
      BeanUtils.copyProperties(dictType, vo);
      vo.setCreateTime(TimeUtils.timestampToDate(dictType.getCreateTime()));
      vo.setUpdateTime(TimeUtils.timestampToDate(dictType.getUpdateTime()));
      return vo;
   }

   public void add(DictTypeCreateValidate createValidate) {
      Assert.isNull(this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id"}).eq("dict_name", createValidate.getDictName())).eq("is_delete", 0)).last("limit 1")), "字典名称已存在！", new Object[0]);
      Assert.isNull(this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id"}).eq("dict_type", createValidate.getDictType())).eq("is_delete", 0)).last("limit 1")), "字典类型已存在！", new Object[0]);
      DictType model = new DictType();
      model.setDictName(createValidate.getDictName());
      model.setDictType(createValidate.getDictType());
      model.setDictRemark(createValidate.getDictRemark());
      model.setDictStatus(createValidate.getDictStatus());
      model.setCreateTime(System.currentTimeMillis() / 1000L);
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.dictTypeMapper.insert(model);
   }

   public void edit(DictTypeUpdateValidate updateValidate) {
      DictType model = (DictType)this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).eq("id", updateValidate.getId())).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(model, "字典类型不存在！", new Object[0]);
      Assert.isNull(this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).ne("id", updateValidate.getId())).eq("dict_name", updateValidate.getDictName())).eq("is_delete", 0)).last("limit 1")), "字典类型已存在！", new Object[0]);
      Assert.isNull(this.dictTypeMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).ne("id", updateValidate.getId())).eq("dict_type", updateValidate.getDictType())).eq("is_delete", 0)).last("limit 1")), "字典类型已存在！", new Object[0]);
      model.setDictName(updateValidate.getDictName());
      model.setDictType(updateValidate.getDictType());
      model.setDictRemark(updateValidate.getDictRemark());
      model.setDictStatus(updateValidate.getDictStatus());
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.dictTypeMapper.updateById(model);
   }

   public void del(List<Integer> ids) {
      Iterator var2 = ids.iterator();

      while(var2.hasNext()) {
         Integer id = (Integer)var2.next();
         DictType model = new DictType();
         model.setId(id);
         model.setIsDelete(1);
         model.setDeleteTime(System.currentTimeMillis() / 1000L);
         this.dictTypeMapper.updateById(model);
      }

   }
}
